import {request} from '../../../util/api'
import Qs from 'qs'

/**
 *1.新增字典数据
 *2.修改字典数据
 *3.查询字典数据列表
 *4.查询字典数据详细
 *5.删除字典数据
 *6.导入字典数据信息
 *7.导出字典数据
 *---------------------------
 * 8.根据字典类型查询字典数据信息
 * 9.下载字典数据导入模板
 */

// 1.新增字典数据
export function addData(data) {
  data = Qs.stringify(data)
  return request({
    url: '/system/dict/data/add',
    method: 'post',
    data: data,
    headers: {}
  })
}

// 2.修改字典数据
export function updateData(data) {
  const businessId = data.businessId
  data = Qs.stringify(data)
  return request({
    url: '/system/dict/data/update/' + businessId,
    method: 'put',
    data: data,
    headers: {}
  })
}

// 3.查询字典数据列表
export function listData(query) {
  return request({
    url: '/system/dict/data/list',
    method: 'get',
    params: query
  })
}

// 4.查询字典数据详细
export function getData(dictCode) {
  return request({
    url: '/system/dict/data/detail/' + dictCode,
    method: 'get'
  })
}

// 5.删除字典数据
export function delData(dictCode) {
  return request({
    url: '/system/dict/data/deleteLogical/' + dictCode,
    method: 'delete',
    headers: {}
  })
}

// 6.导入字典数据信息
export function importExcel(data) {
  return request({
    url: '/system/dict/data/importDictData',
    method: 'post',
    headers: {
      'Content-Type': 'multipart/form-data'
    },
    transformRequest: [(data) => {
      return data
    }],
    data
  })
}

// 7.导出字典数据
export function exportData(query) {
  return request({
    url: '/system/dict/data/export',
    method: 'get',
    params: query,
    responseType: 'blob'
  })
}

// 8.根据字典类型查询字典数据信息
export function getDict(dictType) {
  return request({
    url: '/system/dict/data/type/' + dictType,
    method: 'get'
  })
}

// 9.下载字典数据导入模板
export function importTemplate(params) {
  return request({
    url: '/system/dict/data/importTemplate',
    method: 'get',
    responseType: 'blob',
    params
  })
}

